@@ -1,3 +1,6 @@
+import os
+import ConfigParser
+
 from flask import Flask, redirect
 from flask.templating import render_template_string
 from moksha.common.lib.helpers import get_moksha_appconfig
@@ -58,9 +61,27 @@ def basic(widget_name):
     )
 
 
+def load_production_config(fname):
+    """ Extract /etc/narcissus.ini into a dict """
+
+    parser = ConfigParser.ConfigParser()
+    parser.read(fname)
+
+    opts = parser.options("app:main")
+    get = lambda key: parser.get("app:main", key)
+
+    config = dict(zip(opts, map(get, opts)))
+
+    return config
+
+
 def main():
-    # Load development.ini
-    config = get_moksha_appconfig()
+    production_filename = "/etc/narcissus.ini"
+    if os.path.exists(production_filename):
+        config = load_production_config(production_filename)
+    else:
+        # Load development.ini
+        config = get_moksha_appconfig()
 
     # Wrap the inner wsgi app with our middlewares
     app.wsgi_app = make_moksha_middleware(app.wsgi_app, config)
@@ -72,5 +93,6 @@ def main():
         port=int(config.get('port', '5000')),
     )
 
+
 if __name__ == "__main__":
     main()
